//
//  WTContinuousCloudRecognitionViewController.m
//  Native Examples
//
//  Created by Andreas Schacherbauer on 29/07/15.
//  Copyright (c) 2015 Wikitude. All rights reserved.
//

#import "WTContinuousCloudRecognitionViewController.h"

#import <WikitudeNativeSDK/WikitudeNativeSDK.h>

#import "WikitudeLicense.h"
#import "StrokedRectangle.h"
#import "ExternalRenderer.h"


@interface WTContinuousCloudRecognitionViewController () <WTWikitudeNativeSDKDelegate, WTCloudTrackerDelegate>

@property (nonatomic, strong) WTWikitudeNativeSDK                           *wikitudeSDK;
@property (nonatomic, strong) WTCloudTracker                                *cloudTracker;

@property (nonatomic, strong) EAGLContext                                   *sharedWikitudeEAGLCameraContext;

@property (nonatomic, copy) WTWikitudeUpdateHandler                         wikitudeUpdateHandler;
@property (nonatomic, copy) WTWikitudeDrawHandler                           wikitudeDrawHandler;

@property (nonatomic, assign) BOOL                                          isTracking;

@property (nonatomic, assign) BOOL                                          isContinuousRecognitionActive;

@property (nonatomic, strong) ExternalRenderer                              *renderer;
@property (nonatomic, strong) StrokedRectangle                              *renderableRectangle;

@end

@implementation WTContinuousCloudRecognitionViewController

#pragma mark UIViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    self.renderer = [[ExternalRenderer alloc] init];
    self.renderableRectangle = [[StrokedRectangle alloc] init];
    self.renderableRectangle.scale = 320.0f;

    self.wikitudeSDK = [[WTWikitudeNativeSDK alloc] initWithRenderingMode:WTRenderingMode_External delegate:self];
    [self.wikitudeSDK setLicenseKey:kWTLicenseKey];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];

    [self.renderer setupRenderingWithLayer:[self.eaglView eaglLayer]];
    [self.renderer startRenderLoopWithRenderBlock:[self renderBlock]];

    [self.wikitudeSDK start:nil completion:^(BOOL isRunning, NSError * __nonnull error) {
        if ( !isRunning ) {
            NSLog(@"Wikitude SDK is not running. Reason: %@", [error localizedDescription]);
        }
        else
        {
            self.cloudTracker = [self.wikitudeSDK.trackerManager createCloudTrackerWithToken:@"b277eeadc6183ab57a83b07682b3ceba" targetCollectionId:@"54e4b9fe6134bb74351b2aa3" extendedTargets:nil andDelegate:self];
        }
    }];
}

- (void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:animated];
    
    [self.wikitudeSDK stop];

    [self.renderer stopRenderLoop];
    [self.renderer teardownRendering];
}

- (void)viewWillTransitionToSize:(CGSize)size withTransitionCoordinator:(id<UIViewControllerTransitionCoordinator>)coordinator
{
    [super viewWillTransitionToSize:size withTransitionCoordinator:coordinator];

    [self.wikitudeSDK shouldTransitionToSize:size withTransitionCoordinator:coordinator];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Actions
- (IBAction)toggleContinuousRecognition:(id)sender {    
    
    self.isContinuousRecognitionActive = !self.isContinuousRecognitionActive;
    
    if ( self.isContinuousRecognitionActive )
    {
        if ( self.cloudTracker && self.cloudTracker.isLoaded )
        {
            [self.cloudTracker startContinuousRecognitionWithInterval:1.5 successHandler:^(WTCloudRecognitionResponse *response) {
                NSLog(@"received continuous response...");
                if ( response.recognized ) {
                    dispatch_async(dispatch_get_main_queue(), ^{
                        [self.cloudTracker stopContinuousRecognition];
                        [self.continuousRecognitionButton setTitle:@"Start Continuous Recognition" forState:UIControlStateNormal];
                    });
                }
            } interruptionHandler:nil errorHandler:^(NSError *error) {
            }];
            [self.continuousRecognitionButton setTitle:@"Stop Continuous Recognition" forState:UIControlStateNormal];
        }
        else
        {
            NSLog(@"Cloud tracker is not ready yet. Wait for -cloud");
        }
    }
    else
    {
        [self.cloudTracker stopContinuousRecognition];
        [self.continuousRecognitionButton setTitle:@"Start Continuous Recognition" forState:UIControlStateNormal];
    }
}


#pragma mark - ExternalRenderer render loop
- (ExternalRenderBlock)renderBlock
{
    return ^ (CADisplayLink *displayLink) {
        if ( self.wikitudeUpdateHandler
            &&
            self.wikitudeDrawHandler )
        {
            self.wikitudeUpdateHandler();
            self.wikitudeDrawHandler();
        }

        [self.renderer bindBuffer];

        if ( _isTracking )
        {
            [self.renderableRectangle drawInContext:[self.renderer internalContext]];
        }
    };
}

#pragma mark - Delegation
#pragma mark WTWikitudeNativeSDKDelegte
- (void)wikitudeNativeSDK:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK didCreatedExternalUpdateHandler:(WTWikitudeUpdateHandler __nonnull)updateHandler
{
    self.wikitudeUpdateHandler = updateHandler;
}

- (void)wikitudeNativeSDK:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK didCreatedExternalDrawHandler:(WTWikitudeDrawHandler __nonnull)drawHandler
{
    self.wikitudeDrawHandler = drawHandler;
}

- (EAGLContext *)eaglContextForVideoCameraInWikitudeNativeSDK:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK
{
    if (!_sharedWikitudeEAGLCameraContext )
    {
        EAGLContext *rendererContext = [self.renderer internalContext];
        self.sharedWikitudeEAGLCameraContext = [[EAGLContext alloc] initWithAPI:[rendererContext API] sharegroup:[rendererContext sharegroup]];
    }
    return self.sharedWikitudeEAGLCameraContext;
}

- (CGRect)eaglViewSizeForExternalRenderingInWikitudeNativeSDK:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK
{
    return self.eaglView.bounds;
}

- (void)wikitudeNativeSDK:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK didEncounterInternalError:(NSError * __nonnull)error
{
    NSLog(@"Internal Wikitude SDK error encounterd. %@", [error localizedDescription]);
}

#pragma mark WTCloudTrackerDelegate
- (void)baseTracker:(nonnull WTBaseTracker *)baseTracker didRecognizedTarget:(nonnull WTImageTarget *)recognizedTarget
{
    NSLog(@"recognized target '%@'", [recognizedTarget name]);
    _isTracking = YES;
}

- (void)baseTracker:(nonnull WTBaseTracker *)baseTracker didTrackTarget:(nonnull WTImageTarget *)trackedTarget
{
    [self.renderableRectangle setProjectionMatrix:trackedTarget.projection];
    [self.renderableRectangle setModelViewMatrix:trackedTarget.modelView];
}

- (void)baseTracker:(nonnull WTBaseTracker *)baseTracker didLostTarget:(nonnull WTImageTarget *)lostTarget
{
    NSLog(@"lost target '%@'", [lostTarget name]);
    _isTracking = NO;
}

- (void)cloudTrackerFinishedLoading:(WTCloudTracker * __nonnull)cloudTracker
{
    NSLog(@"Cloud tracker is loaded");
}

- (void)cloudTracker:(WTCloudTracker * __nonnull)cloudTracker failedToLoadWithError:(NSError * __nonnull)error
{
    NSLog(@"Cloud tracker failed to load with error: %@", [error localizedDescription]);
}

@end
