//
//  WTRecordTrackingMapViewController.m
//  Native Examples
//
//  Created by Andreas Schacherbauer on 01/10/15.
//  Copyright © 2015 Wikitude. All rights reserved.
//

#import "WTRecordTrackingMapViewController.h"

#import <WikitudeNativeSDK/WikitudeNativeSDK.h>

#import "WikitudeLicense.h"


@interface WTRecordTrackingMapViewController () <WTWikitudeNativeSDKDelegate, WTTrackingMapRecorderDelegate, UITextFieldDelegate>

@property (nonatomic, strong) WTWikitudeNativeSDK               *wikitudeSDK;

@property (nonatomic, strong) WTEAGLView                        *wikitudeEAGLView;
@property (nonatomic, strong) WTRenderer                        *wikitudeRenderer;

@property (nonatomic, strong) NSString                          *recordedTrackingMapName;

@end

@implementation WTRecordTrackingMapViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    self.wikitudeSDK = [[WTWikitudeNativeSDK alloc] initWithRenderingMode:WTRenderingMode_Internal delegate:self];
    [self.wikitudeSDK setLicenseKey:kWTLicenseKey];

    [[self.wikitudeSDK trackingMapRecorder] setDelegate:self];

    self.wikitudeRenderer = [self.wikitudeSDK createRenderer];
    self.wikitudeEAGLView = [self.wikitudeSDK createEAGLView];

    [self.wikitudeEAGLView setRenderer:self.wikitudeRenderer];
    
    [self.view insertSubview:self.wikitudeEAGLView atIndex:0];
    [self.wikitudeEAGLView setTranslatesAutoresizingMaskIntoConstraints:NO];

    NSDictionary *views = NSDictionaryOfVariableBindings(_wikitudeEAGLView);
    [self.view addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"|[_wikitudeEAGLView]|" options:0 metrics:nil views:views]];
    [self.view addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"V:|[_wikitudeEAGLView]|" options:0 metrics:nil views:views]];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    [self.wikitudeSDK start:nil completion:^(BOOL isRunning, NSError * _Nonnull error) {
        if ( !isRunning ) {
            NSLog(@"Wikitude SDK is not running. Reason: %@", [error localizedDescription]);
        }
    }];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];

    __weak typeof(self) weakSelf = self;
    UIAlertController *mapNameInputAlertController = [UIAlertController alertControllerWithTitle:@"Tracking Map Name" message:@"Please enter the name for your Tracking Map" preferredStyle:UIAlertControllerStyleAlert];
    [mapNameInputAlertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
        NSString *formatString = [NSDateFormatter dateFormatFromTemplate:@"dMMM' 'HH':'mm':'ss" options:0 locale:[NSLocale currentLocale]];
        [dateFormatter setDateFormat:formatString];
        textField.placeholder = [NSString stringWithFormat:@"Tracking Map | %@", [dateFormatter stringFromDate:[NSDate date]]];
        textField.delegate = weakSelf;
    }];

    UIAlertAction *cancelMapNameInputAction = [UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction * _Nonnull action) {
        [weakSelf performSegueWithIdentifier:@"unwindToExampleOverview" sender:weakSelf];
    }];
    UIAlertAction *useMapNameInputAction = [UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        [weakSelf.toggleMapRecordingButton setEnabled:YES];
    }];
    [mapNameInputAlertController addAction:cancelMapNameInputAction];
    [mapNameInputAlertController addAction:useMapNameInputAction];

    [self presentViewController:mapNameInputAlertController animated:YES completion:nil];
}

- (void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:animated];

    [self dismissTrackingMapRecordingNavigationBarPrompt];
    [self.wikitudeSDK stop];
}

- (void)viewWillTransitionToSize:(CGSize)size withTransitionCoordinator:(id<UIViewControllerTransitionCoordinator>)coordinator
{
    [super viewWillTransitionToSize:size withTransitionCoordinator:coordinator];
    
    [self.wikitudeSDK shouldTransitionToSize:size withTransitionCoordinator:coordinator];
}

- (void)viewDidLayoutSubviews
{
    [super viewDidLayoutSubviews];
    [self.wikitudeSDK shouldTransitionToSize:self.view.bounds.size withTransitionCoordinator:nil];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)toggleMapRecordingState:(UIButton *)sender
{
    if ( [self.wikitudeSDK isRunning] )
    {
        if ( ![[self.wikitudeSDK trackingMapRecorder] isRecording] )
        {
            [[self.wikitudeSDK trackingMapRecorder] startTrackingMapRecording:^(BOOL isRecording, NSError * _Nullable error) {
                NSString *trackingMapRecordingButtonTitle = @"Unable to start 3D Tracking Map Recording";
                if ( isRecording )
                {
                    trackingMapRecordingButtonTitle = @"Stop 3D Tracking Map Recording";
                }
                else
                {
                    NSLog(@"%@. Reason: %@", trackingMapRecordingButtonTitle, [error localizedDescription]);
                }
                [sender setTitle:trackingMapRecordingButtonTitle forState:UIControlStateNormal];
            }];
        }
        else
        {
            __weak typeof(self) weakSelf = self;
            [[self.wikitudeSDK trackingMapRecorder] stopTrackingMapRecording:self.recordedTrackingMapName completion:^(NSURL *trackingMapFileURL, NSError *error) {

                [weakSelf.navigationItem setPrompt:nil];
            
                NSString *trackingMapRecordingButtonTitle = @"Unable to save 3D tracking map";
                if ( !trackingMapFileURL ) {
                    NSLog(@"%@. Reason: %@", trackingMapRecordingButtonTitle, [error localizedDescription]);
                    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"Error Saving Tracking Map" message:[error localizedDescription] preferredStyle:UIAlertControllerStyleAlert];
                    UIAlertAction *defaultAction = [UIAlertAction actionWithTitle:@"Restart" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
                        [weakSelf performSegueWithIdentifier:@"unwindToExampleOverview" sender:weakSelf];
                    }];
                    [alertController addAction:defaultAction];
                    [weakSelf presentViewController:alertController animated:YES completion:nil];
                }
                else
                {
                    UIAlertController *savedMapAlterController = [UIAlertController alertControllerWithTitle:@"Tracking Map Saved" message:@"Would you like to keep the recorded Tracking Map or delete it?" preferredStyle:UIAlertControllerStyleAlert];
                    UIAlertAction *deleteRecordedTrackingMapAction = [UIAlertAction actionWithTitle:@"Delete" style:UIAlertActionStyleDestructive handler:^(UIAlertAction * _Nonnull action) {
                        if ( [[NSFileManager defaultManager] fileExistsAtPath:[trackingMapFileURL absoluteString]] )
                        {
                            NSError *trackingMapDeletionError = nil;
                            BOOL trackingMapRemoved = [[NSFileManager defaultManager] removeItemAtPath:[trackingMapFileURL absoluteString] error:&trackingMapDeletionError];
                            if ( !trackingMapRemoved )
                            {
                                NSLog(@"Unable to remove Tracking Map at URL '%@'. Reason: %@", [trackingMapFileURL absoluteString], [trackingMapDeletionError localizedDescription]);
                            }
                        }
                        [weakSelf performSegueWithIdentifier:@"unwindToExampleOverview" sender:weakSelf];
                    }];
                    UIAlertAction *doneRecordingTrackingMapAction = [UIAlertAction actionWithTitle:@"Keep" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
                        [weakSelf performSegueWithIdentifier:@"unwindToExampleOverview" sender:weakSelf];
                    }];
                    [savedMapAlterController addAction:deleteRecordedTrackingMapAction];
                    [savedMapAlterController addAction:doneRecordingTrackingMapAction];

                    [weakSelf presentViewController:savedMapAlterController animated:YES completion:nil];

                    trackingMapRecordingButtonTitle = @"Start 3D Tracking Map Recording";
                }
            }];

            [self dismissTrackingMapRecordingNavigationBarPrompt];
            [self.navigationController.navigationBar setBarTintColor:[UIColor whiteColor]];
            [self.navigationItem setPrompt:@"Saving Tracking Map..."];
        }
    }
    else
    {
        NSString *trackingMapRecordingButtonTitle = @"Start 3D Tracking Map Recording";
        [sender setTitle:trackingMapRecordingButtonTitle forState:UIControlStateNormal];
        NSLog(@"The Wikitude SDK must be running in order to start/stop 3D Tracking Map recordings");
    }
}

#pragma mark - Delegation
#pragma mark WTWikitudeNativeSDKDelegte
- (WTCustomUpdateHandler)wikitudeNativeSDKNeedsExternalUpdateHandler:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK
{
    /* Intentionally returning a nil handler here */
//    return ^(){ };
    return nil;
}

- (WTCustomDrawHandler)wikitudeNativeSDKNeedsExternalDrawHandler:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK
{
//    return ^(){ };
    return nil;
}

- (void)wikitudeNativeSDK:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK didEncounterInternalError:(NSError * __nonnull)error
{
    NSLog(@"Internal Wikitude SDK error encounterd. %@", [error localizedDescription]);
}

#pragma mark WTTrackingMapRecorderDelegate
- (void)trackingMapRecorder:(WTTrackingMapRecorder *)trackingMapRecorder didChangeTrackingMapRecordingQualityFrom:(WTTrackingMapRecordingQuality)oldTrackingQuality toQuality:(WTTrackingMapRecordingQuality)newTrackingQuality
{
    UIColor *trackingMapRecordingQualityBarTintColor = nil;
    NSString *trackingMapRecordingQualityText = nil;

    if ( WTTrackingMapRecordingQuality_Bad == newTrackingQuality )
    {
        trackingMapRecordingQualityBarTintColor = [UIColor colorWithRed:1 green:0.204 blue:0.125 alpha:1];
        trackingMapRecordingQualityText = @"Bad";
    }
    else if ( WTTrackingMapRecordingQuality_Average == newTrackingQuality )
    {
        trackingMapRecordingQualityBarTintColor = [UIColor colorWithRed:1 green:0.851 blue:0 alpha:1];
        trackingMapRecordingQualityText = @"Average";
    }
    else
    {
        trackingMapRecordingQualityBarTintColor = [UIColor colorWithRed:0.420 green:1 blue:0 alpha:1];
        trackingMapRecordingQualityText = @"Good";
    }

    if ( trackingMapRecordingQualityBarTintColor
        &&
         trackingMapRecordingQualityText )
    {
        [self.navigationController.navigationBar setBarTintColor:trackingMapRecordingQualityBarTintColor];
        [self.navigationItem setPrompt:[NSString stringWithFormat:@"Recorded Tracking Map Quality: %@", trackingMapRecordingQualityText]];
    }
}

#pragma mark UITextFieldDelegate
- (BOOL)textFieldShouldEndEditing:(UITextField *)textField
{
    if ( 0 == [textField.text length] )
    {
        self.recordedTrackingMapName = textField.placeholder;
    }
    else
    {
        self.recordedTrackingMapName = textField.text;
    }

    return YES;
}

#pragma mark - Private Methods
- (void)dismissTrackingMapRecordingNavigationBarPrompt
{
    if ( nil != self.navigationItem.prompt )
    {
        [self.navigationController.navigationBar setBarTintColor:[UIColor whiteColor]];
        [self.navigationItem setPrompt:nil];
    }
}

@end
