//
//  WTRecognizedTarget.h
//  WikitudeNativeSDK
//
//  Created by Andreas Schacherbauer on 28/04/15.
//  Copyright (c) 2015 Wikitude. All rights reserved.
//

#import <Foundation/Foundation.h>


NS_ASSUME_NONNULL_BEGIN

/**
 * WTImageTarget represents image targets that are found any kind of tracker.
 */
@interface WTImageTarget : NSObject

/**
 * @brief The name of the image target
 *
 * @return name The name of the image target (Usually it’s file name without extension)
 */
@property (nonatomic, strong, readonly) NSString                    *name;

/**
 * @brief The distance from the camera to the image target in millimeter.
 *
 * This value only contains reliable values if the .wtc file or the cloud archive included physical image target heights.
 *
 * @return distanceToTarget The physical distance in millimeter between the camera and the image target.
 */
@property (nonatomic, assign, readonly) unsigned int                distanceToTarget;

/**
 * @brief A 4x4 projection matrix that can be used to define how a image target is projected in 3d space.
 *
 * Might be set to NULL
 *
 * @return projection A 4x4 projection matrix that can be used to project a image target in a 3d space.
 */
@property (nonatomic, assign, readonly) const float*                projection;

/**
 * @brief A 4x4 modelView matrix that represents translation and rotation of a image target.
 *
 * Might be set to NULL
 *
 * @return modelView A 4x4 matrix that defines translation and rotation of a image target in a 3d space.
 */
@property (nonatomic, assign, readonly) const float*                modelView;

/**
 * @brief A combined model view projection matrix.
 *
 * Might be set to NULL
 *
 * @return modelViewProjection A 4x4 matrix that can be used to render a image target in 3d space.
 */
@property (nonatomic, assign, readonly) const float*                modelViewProjection;

@end

NS_ASSUME_NONNULL_END
