define({ "api": [
  {
    "type": "post",
    "url": "/targetCollection",
    "title": "Create Target Collection",
    "name": "CreateTargetCollection",
    "version": "1.0.0",
    "description": "<p>Create a new target collection in your account.</p> ",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "JSON Body Parameters in the request body in JSON format:": [
          {
            "group": "JSONParam",
            "type": "String",
            "optional": false,
            "field": "name",
            "description": "<p>The name of the new TargetCollection.</p> "
          },
          {
            "group": "JSONParam",
            "type": "JSON",
            "optional": true,
            "field": "metadata",
            "description": "<p>Arbitrary JSON data that should be stored together with the Target Collection.</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection",
            "optional": false,
            "field": "200",
            "description": "<p>The newly created TargetCollection</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_PROPERTY",
            "description": "<p>One or more of the properties you have sent in the body are invalid, or mandatory properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "BODY_CONTENT_TOO_LARGE",
            "description": "<p>The content you have sent in the body exceeds the maximum allowed amount of 1MB.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "delete",
    "url": "/targetCollection/:tcId",
    "title": "Delete Target Collection",
    "name": "DeleteTargetCollection",
    "version": "1.0.0",
    "description": "<p>Delete a particular target collection in your account.</p> ",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be deleted</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "optional": false,
            "field": "204",
            "description": "<p>Empty Response Body</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_GENERATION_IN_PROGRESS",
            "description": "<p>Currently the target collection is being generated into a cloud archive and optimized for recognition. Pleas wait until this process is finished for any further actions.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId/generation",
    "title": "Generate Cloud Archive",
    "name": "GenerateCloudArchive",
    "version": "1.0.0",
    "description": "<p>Generate a Cloud Archive from an existing Target Collection.</p> ",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be generated</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection",
            "optional": false,
            "field": "204",
            "description": "<p>Empty Body</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/CloudArchiveEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_IS_UP_TO_DATE",
            "description": "<p>The TargetCollection does not require a Cloud Archive generation, as no changes have been made since the last generation.</p> "
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_IS_EMPTY",
            "description": "<p>The Cloud Archive cannot be generated, as the corresponding TargetCollection is empty.Please, upload at least one target into the target collection.</p> "
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_GENERATION_IN_PROGRESS",
            "description": "<p>Currently the target collection is being generated into a cloud archive and optimized for recognition. Pleas wait until this process is finished for any further actions.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection",
    "title": "Get all Target Collections",
    "name": "GetAllTargetCollections",
    "version": "1.0.0",
    "description": "<p>Request all target collections in your account.</p> ",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection[]",
            "optional": false,
            "field": "200",
            "description": "<p>The Array of TargetCollections in your account</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId",
    "title": "Get Target Collection",
    "name": "GetTargetCollection",
    "version": "1.0.0",
    "description": "<p>Request a particular target collection in your account.</p> ",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection.</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection",
            "optional": false,
            "field": "200",
            "description": "<p>The particular requested TargetCollection</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId",
    "title": "Update Target Collection",
    "name": "UpdateTargetCollection",
    "version": "1.0.0",
    "description": "<p>Update a target collection in your account.</p> ",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be updated</p> "
          }
        ],
        "JSON Body Parameters in the request body in JSON format:": [
          {
            "group": "JSONParam",
            "type": "String",
            "optional": true,
            "field": "name",
            "description": "<p>The new name of the TargetCollection.</p> "
          },
          {
            "group": "JSONParam",
            "type": "JSON",
            "optional": true,
            "field": "metadata",
            "description": "<p>Arbitrary JSON data that should be stored together with the Target Collection.</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection",
            "optional": false,
            "field": "200",
            "description": "<p>The updated TargetCollection</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_PROPERTY",
            "description": "<p>One or more of the properties you have sent in the body are invalid, or mandatory properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "BODY_CONTENT_TOO_LARGE",
            "description": "<p>The content you have sent in the body exceeds the maximum allowed amount of 1MB.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId/target",
    "title": "Create Target",
    "name": "CreateTarget",
    "version": "1.0.0",
    "description": "<p>Create a new Target in a Target Collection in your account.</p> ",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection the Target will be created in.</p> "
          }
        ],
        "JSON Body Parameters in the request body in JSON format:": [
          {
            "group": "JSONParam",
            "type": "String",
            "optional": false,
            "field": "imageUrl",
            "description": "<p>A remote URL pointing to the image that should be used as Target.</p> "
          },
          {
            "group": "JSONParam",
            "type": "String",
            "optional": true,
            "field": "name",
            "description": "<p>The name of the new Target. If not set, a random name will be assigned to the Target.</p> "
          },
          {
            "group": "JSONParam",
            "type": "JSON",
            "optional": true,
            "field": "metadata",
            "description": "<p>Arbitrary JSON data that should be stored together with the Target.</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Target",
            "optional": false,
            "field": "200",
            "description": "<p>The newly created Target</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_PROPERTY",
            "description": "<p>One or more of the properties you have sent in the body are invalid, or mandatory properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_TARGETNAME_CHARACTERS",
            "description": "<p>The target name you have sent contains illegal characters. Only the following characters are allowed: a-z, A-Z, 0-9, _, -</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "DUPLICATE_TARGETNAME_USAGE",
            "description": "<p>The target name you have sent is already taken by another target in your target collection. Please use a different target name.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "IMAGE_NOT_SUPPORTED",
            "description": "<p>You tried to upload an image in a format which is not supported. Supported image formats are PNG and JPEG (.png, .jpg, .jpeg).</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "BODY_CONTENT_TOO_LARGE",
            "description": "<p>The content you have sent in the body exceeds the maximum allowed amount of 1MB.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "DOWNLOAD_FAILED",
            "description": "<p>The system could not download the file you have specified as Target. Please check the URL and access rights.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "403",
            "optional": false,
            "field": "QUOTA_EXCEEDED_TARGETS",
            "description": "<p>You have reached your quota limit and are not allowed to upload targets anymore.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_GENERATION_IN_PROGRESS",
            "description": "<p>Currently the target collection is being generated into a cloud archive and optimized for recognition. Pleas wait until this process is finished for any further actions.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "delete",
    "url": "/targetCollection/:tcId/target/:targetId",
    "title": "Delete Target",
    "name": "DeleteTarget",
    "version": "1.0.0",
    "description": "<p>Delete a particular Target in your account.</p> ",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection the Target is stored in.</p> "
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "targetId",
            "description": "<p>The id that identifies the Target that should be deleted</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "optional": false,
            "field": "204",
            "description": "<p>Empty Response Body</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target. The target could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_GENERATION_IN_PROGRESS",
            "description": "<p>Currently the target collection is being generated into a cloud archive and optimized for recognition. Pleas wait until this process is finished for any further actions.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId/target/:targetId",
    "title": "Get Target",
    "name": "GetTarget",
    "version": "1.0.0",
    "description": "<p>Request a particular Target in a particular Target Collection.</p> ",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection.</p> "
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "targetId",
            "description": "<p>The id that identifies the Target.</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Target",
            "optional": false,
            "field": "200",
            "description": "<p>The particular requested Target</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target. The target could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId/target",
    "title": "Get Targets",
    "name": "GetTargets",
    "version": "1.0.0",
    "description": "<p>Request targets in a target collection.</p> ",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection.</p> "
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 1.</p> "
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Target[]",
            "optional": false,
            "field": "200",
            "description": "<p>The Array of Targets in the Target Collection</p> "
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p> "
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p> "
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_QUERY_PARAMETER",
            "description": "<p>One or more query parameters are invalid, please check list of allowed values</p> "
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p> "
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p> "
          }
        ]
      }
    }
  }
] });